<?php

declare(strict_types=1);

namespace Serafim\SDL\Keyboard;

interface Key
{
    public const SDLK_UNKNOWN = 0;
    public const SDLK_RETURN = "\r";
    public const SDLK_ESCAPE = "\033";
    public const SDLK_BACKSPACE = "\u{0008}";
    public const SDLK_TAB = "\t";
    public const SDLK_SPACE = ' ';
    public const SDLK_EXCLAIM = '!';
    public const SDLK_QUOTEDBL = '"';
    public const SDLK_HASH = '#';
    public const SDLK_PERCENT = '%';
    public const SDLK_DOLLAR = '$';
    public const SDLK_AMPERSAND = '&';
    public const SDLK_LEFTPAREN = '(';
    public const SDLK_RIGHTPAREN = ')';
    public const SDLK_ASTERISK = '*';
    public const SDLK_PLUS = '+';
    public const SDLK_COMMA = ',';
    public const SDLK_MINUS = '-';
    public const SDLK_PERIOD = '.';
    public const SDLK_SLASH = '/';
    public const SDLK_0 = '0';
    public const SDLK_1 = '1';
    public const SDLK_2 = '2';
    public const SDLK_3 = '3';
    public const SDLK_4 = '4';
    public const SDLK_5 = '5';
    public const SDLK_6 = '6';
    public const SDLK_7 = '7';
    public const SDLK_8 = '8';
    public const SDLK_9 = '9';
    public const SDLK_COLON = ':';
    public const SDLK_SEMICOLON = ';';
    public const SDLK_LESS = '<';
    public const SDLK_EQUALS = '=';
    public const SDLK_GREATER = '>';
    public const SDLK_QUESTION = '?';
    public const SDLK_AT = '@';
    public const SDLK_LEFTBRACKET = '[';
    public const SDLK_RIGHTBRACKET = ']';
    public const SDLK_CARET = '^';
    public const SDLK_UNDERSCORE = '_';
    public const SDLK_BACKQUOTE = '`';
    public const SDLK_a = 'a';
    public const SDLK_b = 'b';
    public const SDLK_c = 'c';
    public const SDLK_d = 'd';
    public const SDLK_e = 'e';
    public const SDLK_f = 'f';
    public const SDLK_g = 'g';
    public const SDLK_h = 'h';
    public const SDLK_i = 'i';
    public const SDLK_j = 'j';
    public const SDLK_k = 'k';
    public const SDLK_l = 'l';
    public const SDLK_m = 'm';
    public const SDLK_n = 'n';
    public const SDLK_o = 'o';
    public const SDLK_p = 'p';
    public const SDLK_q = 'q';
    public const SDLK_r = 'r';
    public const SDLK_s = 's';
    public const SDLK_t = 't';
    public const SDLK_u = 'u';
    public const SDLK_v = 'v';
    public const SDLK_w = 'w';
    public const SDLK_x = 'x';
    public const SDLK_y = 'y';
    public const SDLK_z = 'z';
    public const SDLK_CAPSLOCK = ScanCode::SDL_SCANCODE_CAPSLOCK | (1 << 30);
    public const SDLK_F1 = ScanCode::SDL_SCANCODE_F1 | (1 << 30);
    public const SDLK_F2 = ScanCode::SDL_SCANCODE_F2 | (1 << 30);
    public const SDLK_F3 = ScanCode::SDL_SCANCODE_F3 | (1 << 30);
    public const SDLK_F4 = ScanCode::SDL_SCANCODE_F4 | (1 << 30);
    public const SDLK_F5 = ScanCode::SDL_SCANCODE_F5 | (1 << 30);
    public const SDLK_F6 = ScanCode::SDL_SCANCODE_F6 | (1 << 30);
    public const SDLK_F7 = ScanCode::SDL_SCANCODE_F7 | (1 << 30);
    public const SDLK_F8 = ScanCode::SDL_SCANCODE_F8 | (1 << 30);
    public const SDLK_F9 = ScanCode::SDL_SCANCODE_F9 | (1 << 30);
    public const SDLK_F10 = ScanCode::SDL_SCANCODE_F10 | (1 << 30);
    public const SDLK_F11 = ScanCode::SDL_SCANCODE_F11 | (1 << 30);
    public const SDLK_F12 = ScanCode::SDL_SCANCODE_F12 | (1 << 30);
    public const SDLK_PRINTSCREEN = ScanCode::SDL_SCANCODE_PRINTSCREEN | (1 << 30);
    public const SDLK_SCROLLLOCK = ScanCode::SDL_SCANCODE_SCROLLLOCK | (1 << 30);
    public const SDLK_PAUSE = ScanCode::SDL_SCANCODE_PAUSE | (1 << 30);
    public const SDLK_INSERT = ScanCode::SDL_SCANCODE_INSERT | (1 << 30);
    public const SDLK_HOME = ScanCode::SDL_SCANCODE_HOME | (1 << 30);
    public const SDLK_PAGEUP = ScanCode::SDL_SCANCODE_PAGEUP | (1 << 30);
    public const SDLK_DELETE = "\177";
    public const SDLK_END = ScanCode::SDL_SCANCODE_END | (1 << 30);
    public const SDLK_PAGEDOWN = ScanCode::SDL_SCANCODE_PAGEDOWN | (1 << 30);
    public const SDLK_RIGHT = ScanCode::SDL_SCANCODE_RIGHT | (1 << 30);
    public const SDLK_LEFT = ScanCode::SDL_SCANCODE_LEFT | (1 << 30);
    public const SDLK_DOWN = ScanCode::SDL_SCANCODE_DOWN | (1 << 30);
    public const SDLK_UP = ScanCode::SDL_SCANCODE_UP | (1 << 30);
    public const SDLK_NUMLOCKCLEAR = ScanCode::SDL_SCANCODE_NUMLOCKCLEAR | (1 << 30);
    public const SDLK_KP_DIVIDE = ScanCode::SDL_SCANCODE_KP_DIVIDE | (1 << 30);
    public const SDLK_KP_MULTIPLY = ScanCode::SDL_SCANCODE_KP_MULTIPLY | (1 << 30);
    public const SDLK_KP_MINUS = ScanCode::SDL_SCANCODE_KP_MINUS | (1 << 30);
    public const SDLK_KP_PLUS = ScanCode::SDL_SCANCODE_KP_PLUS | (1 << 30);
    public const SDLK_KP_ENTER = ScanCode::SDL_SCANCODE_KP_ENTER | (1 << 30);
    public const SDLK_KP_1 = ScanCode::SDL_SCANCODE_KP_1 | (1 << 30);
    public const SDLK_KP_2 = ScanCode::SDL_SCANCODE_KP_2 | (1 << 30);
    public const SDLK_KP_3 = ScanCode::SDL_SCANCODE_KP_3 | (1 << 30);
    public const SDLK_KP_4 = ScanCode::SDL_SCANCODE_KP_4 | (1 << 30);
    public const SDLK_KP_5 = ScanCode::SDL_SCANCODE_KP_5 | (1 << 30);
    public const SDLK_KP_6 = ScanCode::SDL_SCANCODE_KP_6 | (1 << 30);
    public const SDLK_KP_7 = ScanCode::SDL_SCANCODE_KP_7 | (1 << 30);
    public const SDLK_KP_8 = ScanCode::SDL_SCANCODE_KP_8 | (1 << 30);
    public const SDLK_KP_9 = ScanCode::SDL_SCANCODE_KP_9 | (1 << 30);
    public const SDLK_KP_0 = ScanCode::SDL_SCANCODE_KP_0 | (1 << 30);
    public const SDLK_KP_PERIOD = ScanCode::SDL_SCANCODE_KP_PERIOD | (1 << 30);
    public const SDLK_APPLICATION = ScanCode::SDL_SCANCODE_APPLICATION | (1 << 30);
    public const SDLK_POWER = ScanCode::SDL_SCANCODE_POWER | (1 << 30);
    public const SDLK_KP_EQUALS = ScanCode::SDL_SCANCODE_KP_EQUALS | (1 << 30);
    public const SDLK_F13 = ScanCode::SDL_SCANCODE_F13 | (1 << 30);
    public const SDLK_F14 = ScanCode::SDL_SCANCODE_F14 | (1 << 30);
    public const SDLK_F15 = ScanCode::SDL_SCANCODE_F15 | (1 << 30);
    public const SDLK_F16 = ScanCode::SDL_SCANCODE_F16 | (1 << 30);
    public const SDLK_F17 = ScanCode::SDL_SCANCODE_F17 | (1 << 30);
    public const SDLK_F18 = ScanCode::SDL_SCANCODE_F18 | (1 << 30);
    public const SDLK_F19 = ScanCode::SDL_SCANCODE_F19 | (1 << 30);
    public const SDLK_F20 = ScanCode::SDL_SCANCODE_F20 | (1 << 30);
    public const SDLK_F21 = ScanCode::SDL_SCANCODE_F21 | (1 << 30);
    public const SDLK_F22 = ScanCode::SDL_SCANCODE_F22 | (1 << 30);
    public const SDLK_F23 = ScanCode::SDL_SCANCODE_F23 | (1 << 30);
    public const SDLK_F24 = ScanCode::SDL_SCANCODE_F24 | (1 << 30);
    public const SDLK_EXECUTE = ScanCode::SDL_SCANCODE_EXECUTE | (1 << 30);
    public const SDLK_HELP = ScanCode::SDL_SCANCODE_HELP | (1 << 30);
    public const SDLK_MENU = ScanCode::SDL_SCANCODE_MENU | (1 << 30);
    public const SDLK_SELECT = ScanCode::SDL_SCANCODE_SELECT | (1 << 30);
    public const SDLK_STOP = ScanCode::SDL_SCANCODE_STOP | (1 << 30);
    public const SDLK_AGAIN = ScanCode::SDL_SCANCODE_AGAIN | (1 << 30);
    public const SDLK_UNDO = ScanCode::SDL_SCANCODE_UNDO | (1 << 30);
    public const SDLK_CUT = ScanCode::SDL_SCANCODE_CUT | (1 << 30);
    public const SDLK_COPY = ScanCode::SDL_SCANCODE_COPY | (1 << 30);
    public const SDLK_PASTE = ScanCode::SDL_SCANCODE_PASTE | (1 << 30);
    public const SDLK_FIND = ScanCode::SDL_SCANCODE_FIND | (1 << 30);
    public const SDLK_MUTE = ScanCode::SDL_SCANCODE_MUTE | (1 << 30);
    public const SDLK_VOLUMEUP = ScanCode::SDL_SCANCODE_VOLUMEUP | (1 << 30);
    public const SDLK_VOLUMEDOWN = ScanCode::SDL_SCANCODE_VOLUMEDOWN | (1 << 30);
    public const SDLK_KP_COMMA = ScanCode::SDL_SCANCODE_KP_COMMA | (1 << 30);
    public const SDLK_KP_EQUALSAS400 = ScanCode::SDL_SCANCODE_KP_EQUALSAS400 | (1 << 30);
    public const SDLK_ALTERASE = ScanCode::SDL_SCANCODE_ALTERASE | (1 << 30);
    public const SDLK_SYSREQ = ScanCode::SDL_SCANCODE_SYSREQ | (1 << 30);
    public const SDLK_CANCEL = ScanCode::SDL_SCANCODE_CANCEL | (1 << 30);
    public const SDLK_CLEAR = ScanCode::SDL_SCANCODE_CLEAR | (1 << 30);
    public const SDLK_PRIOR = ScanCode::SDL_SCANCODE_PRIOR | (1 << 30);
    public const SDLK_RETURN2 = ScanCode::SDL_SCANCODE_RETURN2 | (1 << 30);
    public const SDLK_SEPARATOR = ScanCode::SDL_SCANCODE_SEPARATOR | (1 << 30);
    public const SDLK_OUT = ScanCode::SDL_SCANCODE_OUT | (1 << 30);
    public const SDLK_OPER = ScanCode::SDL_SCANCODE_OPER | (1 << 30);
    public const SDLK_CLEARAGAIN = ScanCode::SDL_SCANCODE_CLEARAGAIN | (1 << 30);
    public const SDLK_CRSEL = ScanCode::SDL_SCANCODE_CRSEL | (1 << 30);
    public const SDLK_EXSEL = ScanCode::SDL_SCANCODE_EXSEL | (1 << 30);
    public const SDLK_KP_00 = ScanCode::SDL_SCANCODE_KP_00 | (1 << 30);
    public const SDLK_KP_000 = ScanCode::SDL_SCANCODE_KP_000 | (1 << 30);
    public const SDLK_THOUSANDSSEPARATOR = ScanCode::SDL_SCANCODE_THOUSANDSSEPARATOR | (1 << 30);
    public const SDLK_DECIMALSEPARATOR = ScanCode::SDL_SCANCODE_DECIMALSEPARATOR | (1 << 30);
    public const SDLK_CURRENCYUNIT = ScanCode::SDL_SCANCODE_CURRENCYUNIT | (1 << 30);
    public const SDLK_CURRENCYSUBUNIT = ScanCode::SDL_SCANCODE_CURRENCYSUBUNIT | (1 << 30);
    public const SDLK_KP_LEFTPAREN = ScanCode::SDL_SCANCODE_KP_LEFTPAREN | (1 << 30);
    public const SDLK_KP_RIGHTPAREN = ScanCode::SDL_SCANCODE_KP_RIGHTPAREN | (1 << 30);
    public const SDLK_KP_LEFTBRACE = ScanCode::SDL_SCANCODE_KP_LEFTBRACE | (1 << 30);
    public const SDLK_KP_RIGHTBRACE = ScanCode::SDL_SCANCODE_KP_RIGHTBRACE | (1 << 30);
    public const SDLK_KP_TAB = ScanCode::SDL_SCANCODE_KP_TAB | (1 << 30);
    public const SDLK_KP_BACKSPACE = ScanCode::SDL_SCANCODE_KP_BACKSPACE | (1 << 30);
    public const SDLK_KP_A = ScanCode::SDL_SCANCODE_KP_A | (1 << 30);
    public const SDLK_KP_B = ScanCode::SDL_SCANCODE_KP_B | (1 << 30);
    public const SDLK_KP_C = ScanCode::SDL_SCANCODE_KP_C | (1 << 30);
    public const SDLK_KP_D = ScanCode::SDL_SCANCODE_KP_D | (1 << 30);
    public const SDLK_KP_E = ScanCode::SDL_SCANCODE_KP_E | (1 << 30);
    public const SDLK_KP_F = ScanCode::SDL_SCANCODE_KP_F | (1 << 30);
    public const SDLK_KP_XOR = ScanCode::SDL_SCANCODE_KP_XOR | (1 << 30);
    public const SDLK_KP_POWER = ScanCode::SDL_SCANCODE_KP_POWER | (1 << 30);
    public const SDLK_KP_PERCENT = ScanCode::SDL_SCANCODE_KP_PERCENT | (1 << 30);
    public const SDLK_KP_LESS = ScanCode::SDL_SCANCODE_KP_LESS | (1 << 30);
    public const SDLK_KP_GREATER = ScanCode::SDL_SCANCODE_KP_GREATER | (1 << 30);
    public const SDLK_KP_AMPERSAND = ScanCode::SDL_SCANCODE_KP_AMPERSAND | (1 << 30);
    public const SDLK_KP_DBLAMPERSAND = ScanCode::SDL_SCANCODE_KP_DBLAMPERSAND | (1 << 30);
    public const SDLK_KP_VERTICALBAR = ScanCode::SDL_SCANCODE_KP_VERTICALBAR | (1 << 30);
    public const SDLK_KP_DBLVERTICALBAR = ScanCode::SDL_SCANCODE_KP_DBLVERTICALBAR | (1 << 30);
    public const SDLK_KP_COLON = ScanCode::SDL_SCANCODE_KP_COLON | (1 << 30);
    public const SDLK_KP_HASH = ScanCode::SDL_SCANCODE_KP_HASH | (1 << 30);
    public const SDLK_KP_SPACE = ScanCode::SDL_SCANCODE_KP_SPACE | (1 << 30);
    public const SDLK_KP_AT = ScanCode::SDL_SCANCODE_KP_AT | (1 << 30);
    public const SDLK_KP_EXCLAM = ScanCode::SDL_SCANCODE_KP_EXCLAM | (1 << 30);
    public const SDLK_KP_MEMSTORE = ScanCode::SDL_SCANCODE_KP_MEMSTORE | (1 << 30);
    public const SDLK_KP_MEMRECALL = ScanCode::SDL_SCANCODE_KP_MEMRECALL | (1 << 30);
    public const SDLK_KP_MEMCLEAR = ScanCode::SDL_SCANCODE_KP_MEMCLEAR | (1 << 30);
    public const SDLK_KP_MEMADD = ScanCode::SDL_SCANCODE_KP_MEMADD | (1 << 30);
    public const SDLK_KP_MEMSUBTRACT = ScanCode::SDL_SCANCODE_KP_MEMSUBTRACT | (1 << 30);
    public const SDLK_KP_MEMMULTIPLY = ScanCode::SDL_SCANCODE_KP_MEMMULTIPLY | (1 << 30);
    public const SDLK_KP_MEMDIVIDE = ScanCode::SDL_SCANCODE_KP_MEMDIVIDE | (1 << 30);
    public const SDLK_KP_PLUSMINUS = ScanCode::SDL_SCANCODE_KP_PLUSMINUS | (1 << 30);
    public const SDLK_KP_CLEAR = ScanCode::SDL_SCANCODE_KP_CLEAR | (1 << 30);
    public const SDLK_KP_CLEARENTRY = ScanCode::SDL_SCANCODE_KP_CLEARENTRY | (1 << 30);
    public const SDLK_KP_BINARY = ScanCode::SDL_SCANCODE_KP_BINARY | (1 << 30);
    public const SDLK_KP_OCTAL = ScanCode::SDL_SCANCODE_KP_OCTAL | (1 << 30);
    public const SDLK_KP_DECIMAL = ScanCode::SDL_SCANCODE_KP_DECIMAL | (1 << 30);
    public const SDLK_KP_HEXADECIMAL = ScanCode::SDL_SCANCODE_KP_HEXADECIMAL | (1 << 30);
    public const SDLK_LCTRL = ScanCode::SDL_SCANCODE_LCTRL | (1 << 30);
    public const SDLK_LSHIFT = ScanCode::SDL_SCANCODE_LSHIFT | (1 << 30);
    public const SDLK_LALT = ScanCode::SDL_SCANCODE_LALT | (1 << 30);
    public const SDLK_LGUI = ScanCode::SDL_SCANCODE_LGUI | (1 << 30);
    public const SDLK_RCTRL = ScanCode::SDL_SCANCODE_RCTRL | (1 << 30);
    public const SDLK_RSHIFT = ScanCode::SDL_SCANCODE_RSHIFT | (1 << 30);
    public const SDLK_RALT = ScanCode::SDL_SCANCODE_RALT | (1 << 30);
    public const SDLK_RGUI = ScanCode::SDL_SCANCODE_RGUI | (1 << 30);
    public const SDLK_MODE = ScanCode::SDL_SCANCODE_MODE | (1 << 30);
    public const SDLK_AUDIONEXT = ScanCode::SDL_SCANCODE_AUDIONEXT | (1 << 30);
    public const SDLK_AUDIOPREV = ScanCode::SDL_SCANCODE_AUDIOPREV | (1 << 30);
    public const SDLK_AUDIOSTOP = ScanCode::SDL_SCANCODE_AUDIOSTOP | (1 << 30);
    public const SDLK_AUDIOPLAY = ScanCode::SDL_SCANCODE_AUDIOPLAY | (1 << 30);
    public const SDLK_AUDIOMUTE = ScanCode::SDL_SCANCODE_AUDIOMUTE | (1 << 30);
    public const SDLK_MEDIASELECT = ScanCode::SDL_SCANCODE_MEDIASELECT | (1 << 30);
    public const SDLK_WWW = ScanCode::SDL_SCANCODE_WWW | (1 << 30);
    public const SDLK_MAIL = ScanCode::SDL_SCANCODE_MAIL | (1 << 30);
    public const SDLK_CALCULATOR = ScanCode::SDL_SCANCODE_CALCULATOR | (1 << 30);
    public const SDLK_COMPUTER = ScanCode::SDL_SCANCODE_COMPUTER | (1 << 30);
    public const SDLK_AC_SEARCH = ScanCode::SDL_SCANCODE_AC_SEARCH | (1 << 30);
    public const SDLK_AC_HOME = ScanCode::SDL_SCANCODE_AC_HOME | (1 << 30);
    public const SDLK_AC_BACK = ScanCode::SDL_SCANCODE_AC_BACK | (1 << 30);
    public const SDLK_AC_FORWARD = ScanCode::SDL_SCANCODE_AC_FORWARD | (1 << 30);
    public const SDLK_AC_STOP = ScanCode::SDL_SCANCODE_AC_STOP | (1 << 30);
    public const SDLK_AC_REFRESH = ScanCode::SDL_SCANCODE_AC_REFRESH | (1 << 30);
    public const SDLK_AC_BOOKMARKS = ScanCode::SDL_SCANCODE_AC_BOOKMARKS | (1 << 30);
    public const SDLK_BRIGHTNESSDOWN = ScanCode::SDL_SCANCODE_BRIGHTNESSDOWN | (1 << 30);
    public const SDLK_BRIGHTNESSUP = ScanCode::SDL_SCANCODE_BRIGHTNESSUP | (1 << 30);
    public const SDLK_DISPLAYSWITCH = ScanCode::SDL_SCANCODE_DISPLAYSWITCH | (1 << 30);
    public const SDLK_KBDILLUMTOGGLE = ScanCode::SDL_SCANCODE_KBDILLUMTOGGLE | (1 << 30);
    public const SDLK_KBDILLUMDOWN = ScanCode::SDL_SCANCODE_KBDILLUMDOWN | (1 << 30);
    public const SDLK_KBDILLUMUP = ScanCode::SDL_SCANCODE_KBDILLUMUP | (1 << 30);
    public const SDLK_EJECT = ScanCode::SDL_SCANCODE_EJECT | (1 << 30);
    public const SDLK_SLEEP = ScanCode::SDL_SCANCODE_SLEEP | (1 << 30);
    public const SDLK_APP1 = ScanCode::SDL_SCANCODE_APP1 | (1 << 30);
    public const SDLK_APP2 = ScanCode::SDL_SCANCODE_APP2 | (1 << 30);
    public const SDLK_AUDIOREWIND = ScanCode::SDL_SCANCODE_AUDIOREWIND | (1 << 30);
    public const SDLK_AUDIOFASTFORWARD = ScanCode::SDL_SCANCODE_AUDIOFASTFORWARD | (1 << 30);
}
