<?php

declare(strict_types=1);

namespace Serafim\SDL\Keyboard;

interface ScanCode
{
    public const SDL_SCANCODE_UNKNOWN = 0;
    public const SDL_SCANCODE_A = 4;
    public const SDL_SCANCODE_B = 5;
    public const SDL_SCANCODE_C = 6;
    public const SDL_SCANCODE_D = 7;
    public const SDL_SCANCODE_E = 8;
    public const SDL_SCANCODE_F = 9;
    public const SDL_SCANCODE_G = 10;
    public const SDL_SCANCODE_H = 11;
    public const SDL_SCANCODE_I = 12;
    public const SDL_SCANCODE_J = 13;
    public const SDL_SCANCODE_K = 14;
    public const SDL_SCANCODE_L = 15;
    public const SDL_SCANCODE_M = 16;
    public const SDL_SCANCODE_N = 17;
    public const SDL_SCANCODE_O = 18;
    public const SDL_SCANCODE_P = 19;
    public const SDL_SCANCODE_Q = 20;
    public const SDL_SCANCODE_R = 21;
    public const SDL_SCANCODE_S = 22;
    public const SDL_SCANCODE_T = 23;
    public const SDL_SCANCODE_U = 24;
    public const SDL_SCANCODE_V = 25;
    public const SDL_SCANCODE_W = 26;
    public const SDL_SCANCODE_X = 27;
    public const SDL_SCANCODE_Y = 28;
    public const SDL_SCANCODE_Z = 29;
    public const SDL_SCANCODE_1 = 30;
    public const SDL_SCANCODE_2 = 31;
    public const SDL_SCANCODE_3 = 32;
    public const SDL_SCANCODE_4 = 33;
    public const SDL_SCANCODE_5 = 34;
    public const SDL_SCANCODE_6 = 35;
    public const SDL_SCANCODE_7 = 36;
    public const SDL_SCANCODE_8 = 37;
    public const SDL_SCANCODE_9 = 38;
    public const SDL_SCANCODE_0 = 39;
    public const SDL_SCANCODE_RETURN = 40;
    public const SDL_SCANCODE_ESCAPE = 41;
    public const SDL_SCANCODE_BACKSPACE = 42;
    public const SDL_SCANCODE_TAB = 43;
    public const SDL_SCANCODE_SPACE = 44;
    public const SDL_SCANCODE_MINUS = 45;
    public const SDL_SCANCODE_EQUALS = 46;
    public const SDL_SCANCODE_LEFTBRACKET = 47;
    public const SDL_SCANCODE_RIGHTBRACKET = 48;
    public const SDL_SCANCODE_BACKSLASH = 49;
    public const SDL_SCANCODE_NONUSHASH = 50;
    public const SDL_SCANCODE_SEMICOLON = 51;
    public const SDL_SCANCODE_APOSTROPHE = 52;
    public const SDL_SCANCODE_GRAVE = 53;
    public const SDL_SCANCODE_COMMA = 54;
    public const SDL_SCANCODE_PERIOD = 55;
    public const SDL_SCANCODE_SLASH = 56;
    public const SDL_SCANCODE_CAPSLOCK = 57;
    public const SDL_SCANCODE_F1 = 58;
    public const SDL_SCANCODE_F2 = 59;
    public const SDL_SCANCODE_F3 = 60;
    public const SDL_SCANCODE_F4 = 61;
    public const SDL_SCANCODE_F5 = 62;
    public const SDL_SCANCODE_F6 = 63;
    public const SDL_SCANCODE_F7 = 64;
    public const SDL_SCANCODE_F8 = 65;
    public const SDL_SCANCODE_F9 = 66;
    public const SDL_SCANCODE_F10 = 67;
    public const SDL_SCANCODE_F11 = 68;
    public const SDL_SCANCODE_F12 = 69;
    public const SDL_SCANCODE_PRINTSCREEN = 70;
    public const SDL_SCANCODE_SCROLLLOCK = 71;
    public const SDL_SCANCODE_PAUSE = 72;
    public const SDL_SCANCODE_INSERT = 73;
    public const SDL_SCANCODE_HOME = 74;
    public const SDL_SCANCODE_PAGEUP = 75;
    public const SDL_SCANCODE_DELETE = 76;
    public const SDL_SCANCODE_END = 77;
    public const SDL_SCANCODE_PAGEDOWN = 78;
    public const SDL_SCANCODE_RIGHT = 79;
    public const SDL_SCANCODE_LEFT = 80;
    public const SDL_SCANCODE_DOWN = 81;
    public const SDL_SCANCODE_UP = 82;
    public const SDL_SCANCODE_NUMLOCKCLEAR = 83;
    public const SDL_SCANCODE_KP_DIVIDE = 84;
    public const SDL_SCANCODE_KP_MULTIPLY = 85;
    public const SDL_SCANCODE_KP_MINUS = 86;
    public const SDL_SCANCODE_KP_PLUS = 87;
    public const SDL_SCANCODE_KP_ENTER = 88;
    public const SDL_SCANCODE_KP_1 = 89;
    public const SDL_SCANCODE_KP_2 = 90;
    public const SDL_SCANCODE_KP_3 = 91;
    public const SDL_SCANCODE_KP_4 = 92;
    public const SDL_SCANCODE_KP_5 = 93;
    public const SDL_SCANCODE_KP_6 = 94;
    public const SDL_SCANCODE_KP_7 = 95;
    public const SDL_SCANCODE_KP_8 = 96;
    public const SDL_SCANCODE_KP_9 = 97;
    public const SDL_SCANCODE_KP_0 = 98;
    public const SDL_SCANCODE_KP_PERIOD = 99;
    public const SDL_SCANCODE_NONUSBACKSLASH = 100;
    public const SDL_SCANCODE_APPLICATION = 101;
    public const SDL_SCANCODE_POWER = 102;
    public const SDL_SCANCODE_KP_EQUALS = 103;
    public const SDL_SCANCODE_F13 = 104;
    public const SDL_SCANCODE_F14 = 105;
    public const SDL_SCANCODE_F15 = 106;
    public const SDL_SCANCODE_F16 = 107;
    public const SDL_SCANCODE_F17 = 108;
    public const SDL_SCANCODE_F18 = 109;
    public const SDL_SCANCODE_F19 = 110;
    public const SDL_SCANCODE_F20 = 111;
    public const SDL_SCANCODE_F21 = 112;
    public const SDL_SCANCODE_F22 = 113;
    public const SDL_SCANCODE_F23 = 114;
    public const SDL_SCANCODE_F24 = 115;
    public const SDL_SCANCODE_EXECUTE = 116;
    public const SDL_SCANCODE_HELP = 117;
    public const SDL_SCANCODE_MENU = 118;
    public const SDL_SCANCODE_SELECT = 119;
    public const SDL_SCANCODE_STOP = 120;
    public const SDL_SCANCODE_AGAIN = 121;
    public const SDL_SCANCODE_UNDO = 122;
    public const SDL_SCANCODE_CUT = 123;
    public const SDL_SCANCODE_COPY = 124;
    public const SDL_SCANCODE_PASTE = 125;
    public const SDL_SCANCODE_FIND = 126;
    public const SDL_SCANCODE_MUTE = 127;
    public const SDL_SCANCODE_VOLUMEUP = 128;
    public const SDL_SCANCODE_VOLUMEDOWN = 129;
    public const SDL_SCANCODE_KP_COMMA = 133;
    public const SDL_SCANCODE_KP_EQUALSAS400 = 134;
    public const SDL_SCANCODE_INTERNATIONAL1 = 135;
    public const SDL_SCANCODE_INTERNATIONAL2 = 136;
    public const SDL_SCANCODE_INTERNATIONAL3 = 137;
    public const SDL_SCANCODE_INTERNATIONAL4 = 138;
    public const SDL_SCANCODE_INTERNATIONAL5 = 139;
    public const SDL_SCANCODE_INTERNATIONAL6 = 140;
    public const SDL_SCANCODE_INTERNATIONAL7 = 141;
    public const SDL_SCANCODE_INTERNATIONAL8 = 142;
    public const SDL_SCANCODE_INTERNATIONAL9 = 143;
    public const SDL_SCANCODE_LANG1 = 144;
    public const SDL_SCANCODE_LANG2 = 145;
    public const SDL_SCANCODE_LANG3 = 146;
    public const SDL_SCANCODE_LANG4 = 147;
    public const SDL_SCANCODE_LANG5 = 148;
    public const SDL_SCANCODE_LANG6 = 149;
    public const SDL_SCANCODE_LANG7 = 150;
    public const SDL_SCANCODE_LANG8 = 151;
    public const SDL_SCANCODE_LANG9 = 152;
    public const SDL_SCANCODE_ALTERASE = 153;
    public const SDL_SCANCODE_SYSREQ = 154;
    public const SDL_SCANCODE_CANCEL = 155;
    public const SDL_SCANCODE_CLEAR = 156;
    public const SDL_SCANCODE_PRIOR = 157;
    public const SDL_SCANCODE_RETURN2 = 158;
    public const SDL_SCANCODE_SEPARATOR = 159;
    public const SDL_SCANCODE_OUT = 160;
    public const SDL_SCANCODE_OPER = 161;
    public const SDL_SCANCODE_CLEARAGAIN = 162;
    public const SDL_SCANCODE_CRSEL = 163;
    public const SDL_SCANCODE_EXSEL = 164;
    public const SDL_SCANCODE_KP_00 = 176;
    public const SDL_SCANCODE_KP_000 = 177;
    public const SDL_SCANCODE_THOUSANDSSEPARATOR = 178;
    public const SDL_SCANCODE_DECIMALSEPARATOR = 179;
    public const SDL_SCANCODE_CURRENCYUNIT = 180;
    public const SDL_SCANCODE_CURRENCYSUBUNIT = 181;
    public const SDL_SCANCODE_KP_LEFTPAREN = 182;
    public const SDL_SCANCODE_KP_RIGHTPAREN = 183;
    public const SDL_SCANCODE_KP_LEFTBRACE = 184;
    public const SDL_SCANCODE_KP_RIGHTBRACE = 185;
    public const SDL_SCANCODE_KP_TAB = 186;
    public const SDL_SCANCODE_KP_BACKSPACE = 187;
    public const SDL_SCANCODE_KP_A = 188;
    public const SDL_SCANCODE_KP_B = 189;
    public const SDL_SCANCODE_KP_C = 190;
    public const SDL_SCANCODE_KP_D = 191;
    public const SDL_SCANCODE_KP_E = 192;
    public const SDL_SCANCODE_KP_F = 193;
    public const SDL_SCANCODE_KP_XOR = 194;
    public const SDL_SCANCODE_KP_POWER = 195;
    public const SDL_SCANCODE_KP_PERCENT = 196;
    public const SDL_SCANCODE_KP_LESS = 197;
    public const SDL_SCANCODE_KP_GREATER = 198;
    public const SDL_SCANCODE_KP_AMPERSAND = 199;
    public const SDL_SCANCODE_KP_DBLAMPERSAND = 200;
    public const SDL_SCANCODE_KP_VERTICALBAR = 201;
    public const SDL_SCANCODE_KP_DBLVERTICALBAR = 202;
    public const SDL_SCANCODE_KP_COLON = 203;
    public const SDL_SCANCODE_KP_HASH = 204;
    public const SDL_SCANCODE_KP_SPACE = 205;
    public const SDL_SCANCODE_KP_AT = 206;
    public const SDL_SCANCODE_KP_EXCLAM = 207;
    public const SDL_SCANCODE_KP_MEMSTORE = 208;
    public const SDL_SCANCODE_KP_MEMRECALL = 209;
    public const SDL_SCANCODE_KP_MEMCLEAR = 210;
    public const SDL_SCANCODE_KP_MEMADD = 211;
    public const SDL_SCANCODE_KP_MEMSUBTRACT = 212;
    public const SDL_SCANCODE_KP_MEMMULTIPLY = 213;
    public const SDL_SCANCODE_KP_MEMDIVIDE = 214;
    public const SDL_SCANCODE_KP_PLUSMINUS = 215;
    public const SDL_SCANCODE_KP_CLEAR = 216;
    public const SDL_SCANCODE_KP_CLEARENTRY = 217;
    public const SDL_SCANCODE_KP_BINARY = 218;
    public const SDL_SCANCODE_KP_OCTAL = 219;
    public const SDL_SCANCODE_KP_DECIMAL = 220;
    public const SDL_SCANCODE_KP_HEXADECIMAL = 221;
    public const SDL_SCANCODE_LCTRL = 224;
    public const SDL_SCANCODE_LSHIFT = 225;
    public const SDL_SCANCODE_LALT = 226;
    public const SDL_SCANCODE_LGUI = 227;
    public const SDL_SCANCODE_RCTRL = 228;
    public const SDL_SCANCODE_RSHIFT = 229;
    public const SDL_SCANCODE_RALT = 230;
    public const SDL_SCANCODE_RGUI = 231;
    public const SDL_SCANCODE_MODE = 257;
    public const SDL_SCANCODE_AUDIONEXT = 258;
    public const SDL_SCANCODE_AUDIOPREV = 259;
    public const SDL_SCANCODE_AUDIOSTOP = 260;
    public const SDL_SCANCODE_AUDIOPLAY = 261;
    public const SDL_SCANCODE_AUDIOMUTE = 262;
    public const SDL_SCANCODE_MEDIASELECT = 263;
    public const SDL_SCANCODE_WWW = 264;
    public const SDL_SCANCODE_MAIL = 265;
    public const SDL_SCANCODE_CALCULATOR = 266;
    public const SDL_SCANCODE_COMPUTER = 267;
    public const SDL_SCANCODE_AC_SEARCH = 268;
    public const SDL_SCANCODE_AC_HOME = 269;
    public const SDL_SCANCODE_AC_BACK = 270;
    public const SDL_SCANCODE_AC_FORWARD = 271;
    public const SDL_SCANCODE_AC_STOP = 272;
    public const SDL_SCANCODE_AC_REFRESH = 273;
    public const SDL_SCANCODE_AC_BOOKMARKS = 274;
    public const SDL_SCANCODE_BRIGHTNESSDOWN = 275;
    public const SDL_SCANCODE_BRIGHTNESSUP = 276;
    public const SDL_SCANCODE_DISPLAYSWITCH = 277;
    public const SDL_SCANCODE_KBDILLUMTOGGLE = 278;
    public const SDL_SCANCODE_KBDILLUMDOWN = 279;
    public const SDL_SCANCODE_KBDILLUMUP = 280;
    public const SDL_SCANCODE_EJECT = 281;
    public const SDL_SCANCODE_SLEEP = 282;
    public const SDL_SCANCODE_APP1 = 283;
    public const SDL_SCANCODE_APP2 = 284;
    public const SDL_SCANCODE_AUDIOREWIND = 285;
    public const SDL_SCANCODE_AUDIOFASTFORWARD = 286;
    public const SDL_SCANCODE_SOFTLEFT = 287;
    public const SDL_SCANCODE_SOFTRIGHT = 288;
    public const SDL_SCANCODE_CALL = 289;
    public const SDL_SCANCODE_ENDCALL = 290;
    public const SDL_NUM_SCANCODES = 512;
}
